# date-diff-js

  

JavaScript library for getting difference between two dates.

  

## Node.js (Install)

  

Requirements:

  

- Node.js

- npm (Node.js package manager)

  

```

npm install date-diff-js

Or

npm install date-diff-js --save

```

  

### Usage

  

Modular include:

```javascript

const  DATE_DIFF = require("date-diff-js");

```

Use in method

```javascript

let  dateDiff = DATE_DIFF(date1, date2, searchString);

```

Input params

- date1, date2 => any date object or date string with any format, Default is current datetime

- searchString => The highest date value you want. Default id 'd' i.e. date

#### searchString List
|Search strings  | Meaning |
|--|--|
| y, Y, Year, Years |Years  |
| m, Month, Months |Months  |
| d, D, Days |Days  |
| h, H, Hours |Hours  |
| M, Minutes  |Minutes  |
| s, S, Seconds  |Seconds  |
| ms, MS, Milliseconds  |Milliseconds  |
| w, W, Weeks  |Weeks  |
  

### dateDiff gives a output object

```javascript
{
	input: 'Input search string',
	output: 'Output value',
	outputs: /* outputs object */
	{
		years: 'years value',
		months: 'months value',
		weeks: 'weeks value',
		days: 'days value',
		hours: 'hours value',
		minutes: 'minutes value',
		seconds: 'seconds value',
		milliseconds: 'milliseconds value'
	},
	totals: /* totals object */
	{
		years: 'Total years diff',
		months: 'Total months diff',
		weeks: 'Total weeks diff',
		days: 'Total days diff',
		minutes: 'Total minutes diff',
		hours: 'Total hours diff',
		seconds: 'Total seconds diff',
		milliseconds: 'Total milliseconds diff',
	}
}

```

  

### SOME EXAMPLES

#### 1. for getting no of days between two dates

```javascript

let  diffDays = DATE_DIFF('2019-07-07', '2019-03-03', 'D').output;

console.log(diffDays);//126

```

#### 2. For getting age ( Ex. birthday July 07, 1991) or year difference

```javascript

let  dateDiff = DATE_DIFF('1991-07-07', 'Y').outputs;

console.log(dateDiff.years +' years '+ dateDiff.months +' months ' + dateDiff.days +' days');//28 years 0 months 21 days

```

#### 3. For getting age ( Ex. birthday July 07, 1991) from definite date like Jan 01, 2019

```javascript

let  dateDiff = DATE_DIFF('1991-07-07', '2019-01-01', 'Y').outputs;

console.log(dateDiff.years +' years '+ dateDiff.months +' months ' + dateDiff.days +' days');//27 years 5 months 25 days

```

#### 4. For getting time difference in hours

```javascript

let  timeDiff = DATE_DIFF('2019-01-01 12:40:28', '2019-01-01 23:59:59', 'H').outputs;

console.log(timeDiff.hours +' hours '+ timeDiff.minutes +' minutes ' + timeDiff.seconds +' seconds');//11 hours 19 minutes 31 seconds

```

#### 5. For getting total difference of two dates in all format like years, months, days etc

```javascript

let  dateDiff = DATE_DIFF('1991-07-07', '2019-01-01', 'Y').totals;

console.log('Total years '+ dateDiff.years +' years');//Total years: 27 years

console.log('Total months '+ dateDiff.months +' months');//Total months: 329 months

console.log('Total days ' + dateDiff.days +' days');//Total days: 10040 days

```
